"""
swUserPreferenceStringValue_e Enumeration

User-preference enumerators for system options and document properties.

Reference:
https://help.solidworks.com/2024/english/api/swconst/SOLIDWORKS.Interop.swconst~SOLIDWORKS.Interop.swconst.swUserPreferenceStringValue_e.html

Status: 🟢
"""

from enum import IntEnum


class SWUserPreferenceStringValueE(IntEnum):
    """User-preference string values for system options and document properties."""

    SW_AUTOSAVE_DIRECTORY = 0
    SW_BACKUP_DIRECTORY = 1
    SW_BOMTABLE_BOMHEADER_CUSTOMTEXT_FORINDENTEDBOM = 2
    SW_BOMTABLE_BOMHEADER_CUSTOMTEXT_FORPARTONLYBOM = 3
    SW_BOMTABLE_BOMHEADER_CUSTOMTEXT_FORTOPLEVELONLYBOM = 4
    SW_BORDER_LAYER = 5
    SW_CENTERLINE_LAYER = 6
    SW_CENTERMARK_LAYER = 7
    SW_COLORS_BACKGROUND_IMAGE_FILE = 8
    SW_CUSTOMPROPERTY_USED_AS_COMPONENT_DESCRIPTION = 9
    SW_DEFAULT_TEMPLATE_ASSEMBLY = 10
    SW_DEFAULT_TEMPLATE_DRAWING = 11
    SW_DEFAULT_TEMPLATE_PART = 12
    SW_DETAILING_AUXVIEWLABELS_CUSTOMNAME = 13
    SW_DETAILING_AUXVIEWLABELS_CUSTOMSCALE = 14
    SW_DETAILING_BOMLOWER_CUSTOMPROPERTY = 15
    SW_DETAILING_BOMUPPER_CUSTOMPROPERTY = 16
    SW_DETAILING_DETAILVIEWLABELS_CUSTOMNAME = 17
    SW_DETAILING_DETAILVIEWLABELS_CUSTOMSCALE = 18
    SW_DETAILING_DIMENSION_STANDARD_NAME = 19
    SW_DETAILING_LAYER = 20
    SW_DETAILING_MISCVIEW_CUSTOMNAME = 21
    SW_DETAILING_MISCVIEW_CUSTOMSCALE = 22
    SW_DETAILING_NEXT_DATUM_FEATURE_LABEL = 23
    SW_DETAILING_ORTHOVIEW_CUSTOMNAME = 24
    SW_DETAILING_ORTHOVIEW_CUSTOMSCALE = 25
    SW_DETAILING_SECTIONVIEWLABELS_CUSTOMNAME = 26
    SW_DETAILING_SECTIONVIEWLABELS_CUSTOMSCALE = 27
    SW_DIMXPERT_GENERAL_TOLERANCE_CUSTOM_TABLE = 28
    SW_DRAFT_STANDARD_EXCLUSION_LIST = 29
    SW_DRAWING_AREA_HATCH_PATTERN = 30
    SW_DRAWING_CUSTOMPROPERTY_USED_AS_REVISION = 31
    SW_ELEC_CABLETRAY_DUCT_NAME = 32
    SW_ELEC_CABLETRAY_ELBOW_NAME = 33
    SW_ELEC_DUCTING_DUCT_NAME = 34
    SW_ELEC_DUCTING_ELBOW_NAME = 35
    SW_EXPORT_IFCTYPE = 36
    SW_EXPORT_OUTPUT_COORDINATE_SYSTEM = 37
    SW_FILELOCATIONS_3DCC_MODEL_FOLDER = 38
    SW_FILELOCATIONS_APPEARANCES = 39
    SW_FILELOCATIONS_BENDNOTE_FORMAT_FILE = 40
    SW_FILELOCATIONS_BENDTABLE = 41
    SW_FILELOCATIONS_BENDTABLE_TEMPLATE = 42
    SW_FILELOCATIONS_BLOCKS = 43
    SW_FILELOCATIONS_BOMTEMPLATES = 44
    SW_FILELOCATIONS_COLOR_SWATCHES = 45
    SW_FILELOCATIONS_CONNECTED_LIBRARY = 46
    SW_FILELOCATIONS_COSTING_REPORT_TEMPLATE_FOLDER = 47
    SW_FILELOCATIONS_COSTING_TEMPLATES = 48
    SW_FILELOCATIONS_CUSTOM_APPEARANCES = 49
    SW_FILELOCATIONS_CUSTOM_DECALS = 50
    SW_FILELOCATIONS_CUSTOM_PROPERTY_FILE = 51
    SW_FILELOCATIONS_CUSTOM_SCENES = 52
    SW_FILELOCATIONS_DEFAULT_SAVE = 53
    SW_FILELOCATIONS_DEFEATURE_RULESETS = 54
    SW_FILELOCATIONS_DESIGN_CHECKER_FILE = 55
    SW_FILELOCATIONS_DESIGN_JOURNAL_TEMPLATE = 56
    SW_FILELOCATIONS_DESIGN_LIBRARY = 57
    SW_FILELOCATIONS_DIMENSION_FAVORITES = 58
    SW_FILELOCATIONS_DOCUMENTS = 59
    SW_FILELOCATIONS_DOCUMENT_TEMPLATES = 60
    SW_FILELOCATIONS_DRAFTING_STANDARD = 61
    SW_FILELOCATIONS_DRAWING_SCALE_STANDARD = 62
    SW_FILELOCATIONS_FUNCBLDR_SEGTYPE_DEFINITIONS = 63
    SW_FILELOCATIONS_GENERAL_TABLES_TEMPLATE = 64
    SW_FILELOCATIONS_HATCH_PATTERN_FILE = 65
    SW_FILELOCATIONS_HOLE_CALLOUT_FORMAT_FILE = 66
    SW_FILELOCATIONS_HOLE_TABLE_TEMPLATES = 67
    SW_FILELOCATIONS_HOLEWIZARD_FAVORITES_DB = 68
    SW_FILELOCATIONS_INSPECTION_EXPORTS = 69
    SW_FILELOCATIONS_INSPECTION_PROJECTS = 70
    SW_FILELOCATIONS_INSPECTION_REPORTS = 71
    SW_FILELOCATIONS_JOURNAL_FILE = 72
    SW_FILELOCATIONS_LIBRARY_FEATURES = 73
    SW_FILELOCATIONS_LIGHTS = 74
    SW_FILELOCATIONS_LINESTYLE_DEFINITIONS = 75
    SW_FILELOCATIONS_MACRO_FEATURES = 76
    SW_FILELOCATIONS_MACROS = 77
    SW_FILELOCATIONS_MATERIAL_DATABASES = 78
    SW_FILELOCATIONS_NEW_SHEET_FORMAT = 79
    SW_FILELOCATIONS_PALETTE_ASSEMBLIES = 80
    SW_FILELOCATIONS_PALETTE_FEATURES = 81
    SW_FILELOCATIONS_PALETTE_FORMTOOLS = 82
    SW_FILELOCATIONS_PALETTE_PARTS = 83
    SW_FILELOCATIONS_PUNCH_TABLE_TEMPLATE = 84
    SW_FILELOCATIONS_REVISION_TABLE_TEMPLATES = 85
    SW_FILELOCATIONS_ROUTE_CABLE_LIBRARY = 86
    SW_FILELOCATIONS_ROUTE_COMPONENT_LIBRARY = 87
    SW_FILELOCATIONS_ROUTE_COVERING_LIBRARY = 88
    SW_FILELOCATIONS_SCENES = 89
    SW_FILELOCATIONS_SEARCH_PATHS = 90
    SW_FILELOCATIONS_SHEET_FORMAT = 91
    SW_FILELOCATIONS_SHEET_METAL_GAUGE_TABLE = 92
    SW_FILELOCATIONS_SPELLING_FOLDERS = 93
    SW_FILELOCATIONS_STRUCTURE_SYSTEMS_CONNECTION_ELEMENTS = 94
    SW_FILELOCATIONS_SUSTAINABILITY_REPORT_TEMPLATE_FOLDER = 95
    SW_FILELOCATIONS_SYMBOL_LIBRARY_FOLDER = 96
    SW_FILELOCATIONS_TEXTURES = 97
    SW_FILELOCATIONS_THEME_FOLDER = 98
    SW_FILELOCATIONS_THREAD_PROFILES = 99
    SW_FILELOCATIONS_TITLEBLOCK_TABLE_TEMPLATE = 100
    SW_FILELOCATIONS_TX_CALLOUT_FORMAT_FILE = 101
    SW_FILELOCATIONS_TX_GENERAL_FILE_LOCATION = 102
    SW_FILELOCATIONS_WEB_FOLDERS = 103
    SW_FILELOCATIONS_WELDMENT_CUTLIST_TEMPLATES = 104
    SW_FILELOCATIONS_WELDMENT_PROFILES = 105
    SW_FILELOCATIONS_WELDMENT_PROPERTY_FILE = 106
    SW_FILELOCATIONS_WELD_TABLE_TEMPLATE = 107
    SW_FILE_SAVEAS_COORDINATE_SYSTEM = 108
    SW_HOLE_TAGS_LIST = 109
    SW_HOLEWIZARD_TOOLBOX_FOLDER = 110
    SW_HVAC_CIR_DUCT_NAME = 111
    SW_HVAC_CIR_ELBOW_NAME = 112
    SW_HVAC_RECT_DUCT_NAME = 113
    SW_HVAC_RECT_ELBOW_NAME = 114
    SW_LAST_SYNCHRONIZATION_TIMESTAMP = 115
    SW_MATERIAL_PROPERTY_CROSSHATCH_PATTERN = 116
    SW_MYSLDSETTINGS = 117
    SW_OPP_PREFIX_SUFFIX_TEXT = 118
    SW_OVERRIDDEN_QUANTITY_COLUMN_NAME = 119
    SW_REFERENCE_TRIAD_XLABEL = 120
    SW_REFERENCE_TRIAD_YLABEL = 121
    SW_REFERENCE_TRIAD_ZLABEL = 122
    SW_SEARCH_DISSECTION_LOCATION = 123
    SW_SEPARATOR_CHARACTER_FOR_DIMS = 124
    SW_SHEETMETAL_BENDNOTES_LAYER = 125
    SW_SHEETMETAL_DESCRIPTION = 126
    SW_SOLIDBODIES_BBOX_DESCRIPTION_FIRST_SEPARATOR = 127
    SW_SOLIDBODIES_BBOX_DESCRIPTION_PREFIX = 128
    SW_SOLIDBODIES_BBOX_DESCRIPTION_SECOND_SEPARATOR = 129
    SW_SOLIDBODIES_BBOX_DESCRIPTION_SUFFIX = 130
    SW_STRUCTURE_SYSTEMS_FOLDER = 131
    SW_VIRTUALCOMPONENT_PREFIXEDIT = 132
    SW_WELDMENT_GENERIC_CUTLIST_ID = 133
    SW_WELDMENT_SHEETMETAL_CUTLIST_ID = 134
    SW_WELDMENT_STRUCTURE_CUTLIST_ID = 135
