"""
swExportDataFileType_e Enumeration

Reference:
https://help.solidworks.com/2024/english/api/swconst/SOLIDWORKS.Interop.swconst~SOLIDWORKS.Interop.swconst.swExportDataFileType_e.html

Status: 🟢
"""

from enum import IntEnum


class SWExportDataFileType_e(IntEnum):
    """Export data file types."""

    SW_EXPORT_PDF_DATA = 1
